@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,7 +12,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -32,6 +32,12 @@
 #include "e-book.h"
 #include "e-name-western.h"
 
+#ifdef G_OS_WIN32
+#include <libedataserver/e-data-server-util.h>
+#undef EVOLUTION_LOCALEDIR
+#define EVOLUTION_LOCALEDIR e_util_get_localedir ()
+#endif
+
 #define d(x)
 
 struct _EContactPrivate {
@@ -357,7 +363,7 @@ e_contact_get_first_attr (EContact *contact, const char *attr_name)
 
 		name = e_vcard_attribute_get_name (attr);
 
-		if (!strcasecmp (name, attr_name))
+		if (!g_ascii_strcasecmp (name, attr_name))
 			return attr;
 	}
 
@@ -702,7 +708,7 @@ e_contact_set_property (GObject *object,
 				attr = l->data;
 				name = e_vcard_attribute_get_name (attr);
 
-				if (!strcasecmp (name, info->vcard_field_name)) {
+				if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
 					if (num_left-- == 0) {
 						found = TRUE;
 						break;
@@ -760,22 +766,22 @@ e_contact_set_property (GObject *object,
 				attr = l->data;
 				name = e_vcard_attribute_get_name (attr);
 
-				if (!strcasecmp (name, info->vcard_field_name)) {
+				if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
 					GList *params;
 
 					for (params = e_vcard_attribute_get_params (attr); params; params = params->next) {
 						EVCardAttributeParam *param = params->data;
 						const char *name = e_vcard_attribute_param_get_name (param);
 
-						if (!strcasecmp (name, EVC_TYPE)) {
+						if (!g_ascii_strcasecmp (name, EVC_TYPE)) {
 							GList *values = e_vcard_attribute_param_get_values (param);
 							if (values && values->data) {
 								gboolean matches = FALSE;
-								if (!found_needed1 && !strcasecmp ((char*)values->data, info->attr_type1)) {
+								if (!found_needed1 && !g_ascii_strcasecmp ((char*)values->data, info->attr_type1)) {
 									found_needed1 = TRUE;
 									matches = TRUE;
 								}
-								else if (!found_needed2 && !strcasecmp ((char*)values->data, info->attr_type2)) {
+								else if (!found_needed2 && !g_ascii_strcasecmp ((char*)values->data, info->attr_type2)) {
 									found_needed2 = TRUE;
 									matches = TRUE;
 								}
@@ -1025,23 +1031,23 @@ e_contact_find_attribute_with_types (EContact *contact, const char *attr_name, c
 
 		name = e_vcard_attribute_get_name (attr);
 
-		if (!strcasecmp (name, attr_name)) {
+		if (!g_ascii_strcasecmp (name, attr_name)) {
 			GList *params;
 
 			for (params = e_vcard_attribute_get_params (attr); params; params = params->next) {
 				EVCardAttributeParam *param = params->data;
 				const char *name = e_vcard_attribute_param_get_name (param);
 
-				if (!strcasecmp (name, EVC_TYPE)) {
+				if (!g_ascii_strcasecmp (name, EVC_TYPE)) {
 					GList *values = e_vcard_attribute_param_get_values (param);
 					if (values && values->data) {
 						gboolean matches = FALSE;
 
-						if (!found_needed1 && !strcasecmp ((char*)values->data, type_needed1)) {
+						if (!found_needed1 && !g_ascii_strcasecmp ((char*)values->data, type_needed1)) {
 							found_needed1 = TRUE;
 							matches = TRUE;
 						}
-						else if (!found_needed2 && !strcasecmp ((char*)values->data, type_needed2)) {
+						else if (!found_needed2 && !g_ascii_strcasecmp ((char*)values->data, type_needed2)) {
 							found_needed2 = TRUE;
 							matches = TRUE;
 						}
@@ -1104,7 +1110,7 @@ e_contact_get_property (GObject *object,
 
 		if (attr) {
 			GList *v = e_vcard_attribute_get_values (attr);
-			rv = v && v->data && !strcasecmp ((char*)v->data, "true");
+			rv = v && v->data && !g_ascii_strcasecmp ((char*)v->data, "true");
 		}
 
 		g_value_set_boolean (value, rv);
@@ -1133,7 +1139,7 @@ e_contact_get_property (GObject *object,
 
 				name = e_vcard_attribute_get_name (attr);
 
-				if (!strcasecmp (name, info->vcard_field_name)) {
+				if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
 					GList *v;
 					int count;
 
@@ -1160,7 +1166,7 @@ e_contact_get_property (GObject *object,
 
 				name = e_vcard_attribute_get_name (attr);
 
-				if (!strcasecmp (name, info->vcard_field_name)) {
+				if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
 					if (num_left-- == 0) {
 						GList *v = e_vcard_attribute_get_values (attr);
 
@@ -1199,7 +1205,7 @@ e_contact_get_property (GObject *object,
 		if (attr)
 			rv = info->struct_getter (contact, attr);
 
-		g_value_set_boxed (value, rv);
+		g_value_take_boxed (value, rv);
 	}
 	else if (info->t & E_CONTACT_FIELD_TYPE_GETSET) {
 		EVCardAttribute *attr = e_contact_get_first_attr (contact, info->vcard_field_name);
@@ -1275,7 +1281,7 @@ e_contact_get_property (GObject *object,
 
 			name = e_vcard_attribute_get_name (attr);
 
-			if (!strcasecmp (name, info->vcard_field_name)) {
+			if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
 				GList *v;
 				v = e_vcard_attribute_get_values (attr);
 
@@ -1620,7 +1626,7 @@ e_contact_get_attributes (EContact *contact, EContactField field_id)
 
 		name = e_vcard_attribute_get_name (attr);
 
-		if (!strcasecmp (name, info->vcard_field_name)) {
+		if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
 			l = g_list_append (l, e_vcard_attribute_copy (attr));
 		}
 	}
@@ -1808,11 +1814,16 @@ e_contact_date_from_string (const char *str)
 {
 	EContactDate* date;
 	int length;
+	char *t;
 
 	g_return_val_if_fail (str != NULL, NULL);
 
 	date = e_contact_date_new();
-	length = strlen(str);
+	/* ignore time part */
+	if ((t = strchr (str, 'T')) != NULL)
+		length = t - str;
+	else
+		length = strlen(str);
 	
 	if (length == 10 ) {
 		date->year = str[0] * 1000 + str[1] * 100 + str[2] * 10 + str[3] - '0' * 1111;
