@@ -285,7 +285,7 @@ add_recipients(GSList *recipient_list, CamelAddress *recipients, int recipient_t
 }
 
 static void 
-send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content, char *buffer, CamelContentType *type, CamelDataWrapper *dw, const char *filename, const char *cid, GSList **attach_list)
+send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content, char *buffer, CamelContentType *type, CamelDataWrapper *dw, const char *filename, const char *encoding, const char *cid, GSList **attach_list)
 {
 	EGwItemLinkInfo *info = NULL;
 	EGwConnectionStatus status;
@@ -321,11 +321,16 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 			temp_str = NULL;
 			temp_len = 0;
 		} else {
-			attachment->data = g_malloc0 (content->buffer->len+1);
-			attachment->data = memcpy (attachment->data, 
-					content->buffer->data, 
-					content->buffer->len);
-			attachment->size = content->buffer->len;
+			if (strlen(encoding) > 0) {
+				attachment->data = g_malloc0 (content->buffer->len+1);
+				attachment->data = memcpy (attachment->data, 
+						content->buffer->data, 
+						content->buffer->len);
+				attachment->size = content->buffer->len;
+			} else {
+				attachment->data = soup_base64_encode(content->buffer->data, content->buffer->len);
+				attachment->size = strlen (attachment->data);
+			}
 		}
 	} else {
 		char *temp_str;
@@ -343,7 +348,8 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 	}
 	
 	if (!strcmp (attachment->contentType, "text/html") || !(strcmp (attachment->contentType, "multipart/alternative"))) {
-		filename = "text.htm";
+		if (!filename)
+			filename = "text.htm";
 		if (!(strcmp (attachment->contentType, "multipart/alternative"))) {
 			g_free (attachment->contentType);
 			attachment->contentType = g_strdup ("text/html");
@@ -415,7 +421,7 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 	/** Get the mime parts from CamelMimemessge **/
 	mp = (CamelMultipart *)camel_medium_get_content_object (CAMEL_MEDIUM (message));
 	if(!mp) {
-		g_error ("ERROR: Could not get content object");
+		g_warning ("ERROR: Could not get content object");
 		camel_operation_end (NULL);
 		return FALSE;
 	}
@@ -442,7 +448,7 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 			e_gw_item_set_content_type (item, content_type);				
 			e_gw_item_set_message (item, buffer);
 		} else {
-			send_as_attachment (cnc, item, content, buffer, type, dw, NULL, NULL, &attach_list);	
+			send_as_attachment (cnc, item, content, buffer, type, dw, NULL, "", NULL, &attach_list);	
 		}
 
 		g_free (buffer);
@@ -586,6 +592,7 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 		char *buffer = NULL;
 		char *mime_type = NULL;
 		const char *content_id = NULL;
+		char *encoding;
 		gboolean is_alternative = FALSE;
 		/*
 		 * XXX:
@@ -615,7 +622,8 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 				disposition = camel_mime_part_get_disposition (temp_part);
 				mime_type = camel_data_wrapper_get_mime_type (temp_dw);
 				cid = camel_mime_part_get_content_id (temp_part);
-				send_as_attachment (cnc, item, temp_content, buffer, type, temp_dw, filename, cid, attach_list);
+				g_print ("%s:%s\n",filename,camel_transfer_encoding_to_string(temp_part->encoding));
+				send_as_attachment (cnc, item, temp_content, buffer, type, temp_dw, filename, "", cid, attach_list);
 				g_free (buffer);
 				g_free (mime_type);
 			}
@@ -628,8 +636,9 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 
 		camel_data_wrapper_write_to_stream(dw, (CamelStream *)content);
 		buffer = g_malloc0 (content->buffer->len+1);
-		buffer = memcpy (buffer, content->buffer->data, content->buffer->len);
+		encoding = camel_transfer_encoding_to_string (part->encoding);
 		filename = camel_mime_part_get_filename (part);
+		buffer = memcpy (buffer, content->buffer->data, content->buffer->len);
 		disposition = camel_mime_part_get_disposition (part);
 		mime_type = camel_data_wrapper_get_mime_type (dw);
 		content_id = camel_mime_part_get_content_id (part);
@@ -638,7 +647,7 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 			e_gw_item_set_content_type (item, mime_type);
 			e_gw_item_set_message (item, buffer);
 		} else {
-			send_as_attachment (cnc, item, content, buffer, type, dw, filename, content_id, attach_list);
+			send_as_attachment (cnc, item, content, buffer, type, dw, filename, encoding, content_id, attach_list);
 		}
 
 		g_free (buffer);
